#
# This file is part of FreedomBox.
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as
# published by the Free Software Foundation, either version 3 of the
# License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#

import pytest

try:
    from pytest_bdd import scenarios
except ImportError:
    pytestmark = pytest.mark.skip(reason='pytest_bdd is not installed')
else:
    from step_definitions.application import *
    from step_definitions.interface import *
    from step_definitions.service import *
    from step_definitions.site import *
    from step_definitions.system import *

    # Mark all tests are functional
    pytestmark = pytest.mark.functional

    scenarios('features')
